"""Create an empty constellation for testing.

Attributes
----------
instruments : list
    List of pysat.Instrument objects

"""

instruments = []
